import django_tables2 as tables
from django.urls import reverse
from django.utils.safestring import mark_safe

from ecobox.models import PointRetrait, Commande, Fournisseur
from lib.tables import StrippedTable
from django_tables2.utils import A


class FournisseurTable(StrippedTable):
    edit = tables.LinkColumn(
        "gestion:ecobox:fournisseur_update",
        text=mark_safe('<i class="fas fa-pencil-alt"></i>'),
        args=[A("pk")],
        attrs={"a": {"class": "btn btn-primary btn-sm"}, "td": {"style": "width: 0px;"}},
        verbose_name="",
        orderable=False,
    )
    delete = tables.Column(
        accessor="pk",
        verbose_name="",
        attrs={"td": {"style": "width: 0px;"}},
    )

    def render_delete(self, record):
        render_str = f"""
        <button type="button" class="btn btn-danger btn-sm" data-toggle="modal" data-target="#fournisseur{record.pk}">
            <i class="fas fa-trash-alt"></i>
        </button>
        <div class="modal fade" id="fournisseur{record.pk}" tabindex="-1" role="dialog" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="exampleModalLongTitle">Suppression d'un fournisseur</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        Voulez-vous vraiment supprimer le fournisseur "<strong>{record.nom}</strong>" ?
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Retour</button>
                        <button type="button" class="btn btn-danger" onclick="location.href='{reverse('gestion:ecobox:fournisseur_delete', args=[record.pk])}'" >Supprimer</button>
                    </div>
                </div>
            </div>
        </div>
        """
        return mark_safe(render_str)

    class Meta(StrippedTable.Meta):
        model = Fournisseur
        fields = ("nom",)


class PointRetraitTable(StrippedTable):
    edit = tables.Column(accessor="adresse", verbose_name="")

    class Meta(StrippedTable.Meta):
        model = PointRetrait
        fields = ("adresse", "edit")

    def render_edit(self, record):
        render_str = f"""
        <a href="{reverse('gestion:ecobox:del_point_retrait', args=[record.pk])}" class="btn btn-danger btn-sm">
        <i class="fas fa-trash-alt"></i></a>
        """
        return mark_safe(render_str)


class CommandeTable(StrippedTable):
    check = tables.CheckBoxColumn(accessor="pk", attrs={"th__input": {"onclick": "toggle(this)"}}, orderable=False)
    contenu = tables.ManyToManyColumn(accessor="elements", verbose_name="Contenu")
    chaine_prix = tables.Column(verbose_name="Prix total", orderable=False)
    actions = tables.Column(accessor="pk")
    user = tables.Column(accessor="pk", verbose_name="Client")

    class Meta(StrippedTable.Meta):
        model = Commande
        fields = (
            "check",
            "date_reservation",
            "user",
            "contenu",
            "chaine_prix",
            "paye",
            "recupere",
            "actions",
            "point_retrait",
        )
        order_by = "point_retrait"

    def render_user(self, record):
        client = record.user.get_link() if record.client_est_inscrit() else record.get_full_name()
        return mark_safe(client + "<br/>" + record.get_phone_link())

    def display_bool(self, yesno, url):
        return mark_safe(
            f"<div style='text-align: center'>{yesno}&nbsp<a href='{url}'><i class='fas fa-sync-alt'></i></a></div>"
        )

    def render_paye(self, record):
        url = reverse("gestion:ecobox:valider_paiement", args=[str(record.pk)])
        yesno = "✔" if record.paye else "✘"
        return self.display_bool(yesno, url)

    def render_recupere(self, record):
        url = reverse("gestion:ecobox:valider_livraison", args=[str(record.pk)])
        yesno = "✔" if record.recupere else "✘"
        return self.display_bool(yesno, url)

    def render_actions(self, record):
        url_valider_annuler = reverse("gestion:ecobox:valider_tout", args=[str(record.pk)])
        url_supprimer = reverse("gestion:ecobox:annuler_commande_admin", args=[str(record.pk)])
        if record.recupere or record.paye:
            title_valider_annuler = "Annuler la livraison et le paiement"
        else:
            title_valider_annuler = "Marquer comme payée et livrée"
        return mark_safe(
            f"""
            <div style='text-align: center'>
            <a href='{url_valider_annuler}' title='{title_valider_annuler}' class='btn btn-primary btn-sm'>
            <i class='fas fa-sync-alt'></i>
            </a>
            <a href='{url_supprimer}' class='btn btn-danger btn-sm'><i class='fas fa-trash-alt'></i></a>
            </div>
            """
        )
